# Secret of Mana Randomizer
It's a multi-mode randomizer for the SNES game Secret of Mana.

Features:
- Open world randomizer - the current most popular mode. Grants Flammie Drum early, and randomly distributes spells, mana seeds, characters, etc. to various locations.
- Vanilla randomizer - randomly swaps enemies, bosses, spells, etc. for a full vanilla run
- Ancient cave - older mode that procedurally generates maps.  Needs work!
- Boss rush - older mode where you fight all bosses in a random order.  Needs work!
- Chaos - older mode where you proceed through randomly-linked vanilla maps.  Needs work!

- For all modes, various optional quality of life improvements and bugfixes.

# Building
Check out and load the .sln in Visual Studio.  I've been using VS 2017.  Anything later than that should theoretically also work.

I'll be posting releases, so unless you're actively working on the project, you shouldn't need to build it.

# Using
Instructions will be here eventually for how to use the rando.  For now join the discord and ask if you have questions.

Releases will be posted here (no music pack)

and also here: https://secretofmanaancientcave.blogspot.com/ (with music pack)

# Contributing
Blerp

# Discord
https://discord.gg/YfmUHqU

We run a weekly open world seed, and this is currently the main source of general information, questions, etc. for the randomizer.
